The Store
---------

.. autoclass:: extended_mypy_django_plugin.plugin._store.Store

.. autoprotocol:: extended_mypy_django_plugin.plugin._store.LookupFunction

.. autoprotocol:: extended_mypy_django_plugin.plugin._store.LookupInstanceFunction

.. autoprotocol:: extended_mypy_django_plugin.plugin._store.GetModelClassByFullname

.. autoprotocol:: extended_mypy_django_plugin.plugin._store.IsInstalledModel

.. autoprotocol:: extended_mypy_django_plugin.plugin._store.KnownConcreteModelsGetter
